badX12: A Python Library for parsing ANSI ASC X12 files.
======================================
.. include:: ./readme.rst


.. toctree::
   :hidden:
   :glob:

   installation
   usage
   modules
   contributing
   authors
   history

